﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2012 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Encodings.PackingEncoding.GroupingVector {
  [Item("SwapGroupingMoveAttribute", "Specifies the tabu attributes for a Swap grouping move on a grouping vector.")]
  [StorableClass]
  public class SwapGroupingMoveAttribute : GroupingMoveAttribute {
    [Storable]
    public int ItemIndex1 { get; protected set; }
    [Storable]
    public int ItemIndex2 { get; protected set; }
    [Storable]
    public int AssignedBin1 { get; protected set; }
    [Storable]
    public int AssignedBin2 { get; protected set; }

    [StorableConstructor]
    protected SwapGroupingMoveAttribute(bool deserializing) : base(deserializing) { }
    protected SwapGroupingMoveAttribute(SwapGroupingMoveAttribute original, Cloner cloner)
      : base(original, cloner) {
      this.ItemIndex1 = original.ItemIndex1;
      this.ItemIndex2 = original.ItemIndex2;
      this.AssignedBin1 = original.AssignedBin1;
      this.AssignedBin2 = original.AssignedBin2;
    }
    public SwapGroupingMoveAttribute() : this(-1, -1, -1, -1, -1) { }
    public SwapGroupingMoveAttribute(int itemIndex1, int itemIndex2, int assignedBin1, int assignedBin2, double moveQuality)
      : base(moveQuality) {
      ItemIndex1 = itemIndex1;
      ItemIndex2 = itemIndex2;
      AssignedBin1 = assignedBin1;
      AssignedBin2 = assignedBin2;
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new SwapGroupingMoveAttribute(this, cloner);
    }
  }
}
